diff --git a/tests/test_renderers/test_fixtures_sphinx.py b/tests/test_renderers/test_fixtures_sphinx.py
index bd0f85eb..65aba83a 100644
--- a/tests/test_renderers/test_fixtures_sphinx.py
+++ b/tests/test_renderers/test_fixtures_sphinx.py
@@ -22,7 +22,12 @@
 def test_syntax_elements(file_params, sphinx_doctree_no_tr: CreateDoctree):
     sphinx_doctree_no_tr.set_conf({"extensions": ["myst_parser"]})
     result = sphinx_doctree_no_tr(file_params.content, "index.md")
-    file_params.assert_expected(result.pformat("index"), rstrip_lines=True)
+    pformat = result.pformat("index")
+    # changed in docutils 0.20.1
+    pformat = pformat.replace(
+        '<literal classes="code" language="">', '<literal classes="code">'
+    )
+    file_params.assert_expected(pformat, rstrip_lines=True)
 
 
 @pytest.mark.param_file(FIXTURE_PATH / "sphinx_link_resolution.md")
@@ -100,6 +105,8 @@ def test_sphinx_directives(file_params, sphinx_doctree_no_tr: CreateDoctree):
         ),
         "",
     )
+    # changed in sphinx 7.3
+    pformat = pformat.replace("Added in version 0.2", "New in version 0.2")
 
     file_params.assert_expected(pformat, rstrip_lines=True)
 
diff --git a/tests/test_sphinx/sourcedirs/heading_slug_func/conf.py b/tests/test_sphinx/sourcedirs/heading_slug_func/conf.py
index f6612b4c..33aed04b 100644
--- a/tests/test_sphinx/sourcedirs/heading_slug_func/conf.py
+++ b/tests/test_sphinx/sourcedirs/heading_slug_func/conf.py
@@ -2,5 +2,6 @@
 
 extensions = ["myst_parser"]
 exclude_patterns = ["_build"]
+suppress_warnings = ["config.cache"]
 myst_heading_anchors = 2
 myst_heading_slug_func = make_id
diff --git a/tests/test_sphinx/test_sphinx_builds.py b/tests/test_sphinx/test_sphinx_builds.py
index fcc1e463..b4e7c10d 100644
--- a/tests/test_sphinx/test_sphinx_builds.py
+++ b/tests/test_sphinx/test_sphinx_builds.py
@@ -162,7 +162,12 @@ def test_references_singlehtml(
             docname="other/other",
             resolve=True,
             regress=True,
-            replace={"other\\other.md": "other/other.md"},
+            replace={
+                "other\\other.md": "other/other.md",
+                # changed in sphinx 7.3
+                '="#document-index': '="index.html#document-index',
+                '="#document-other': '="index.html#document-other',
+            },
         )
 
     get_sphinx_app_output(
@@ -170,7 +175,12 @@ def test_references_singlehtml(
         filename="index.html",
         buildername="singlehtml",
         regress_html=True,
-        replace={"Permalink to this headline": "Permalink to this heading"},
+        replace={
+            "Permalink to this headline": "Permalink to this heading",
+            # changed in sphinx 7.3
+            '="#document-index': '="index.html#document-index',
+            '="#document-other': '="index.html#document-other',
+        },
     )
 
 
@@ -469,7 +479,9 @@ def test_gettext_html(
         regress_ext=".html",
         replace={
             # upstream bug https://github.com/sphinx-doc/sphinx/issues/11689
-            '"Permalink to this heading"': '"Lien permanent vers cette rubrique"'
+            '"Permalink to this heading"': '"Lien permanent vers cette rubrique"',
+            # which was fixed to a different translation in sphinx 7.3
+            '"Lien vers cette rubrique"': '"Lien permanent vers cette rubrique"',
         },
     )
 
